<?php

namespace Drupal\visitors\Controller\Report;

use Drupal\Core\Datetime\DateFormatterInterface;
use Drupal\Core\Form\FormBuilderInterface;
use Drupal\Core\StringTranslation\TranslationInterface;
use Drupal\visitors\VisitorsReportInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Day of Month Report controller.
 */
class DeviceController extends ReportController {
  /**
   * The date service.
   *
   * @var \Drupal\Core\Datetime\DateFormatterInterface
   */
  protected $date;

  /**
   * The form builder service.
   *
   * @var \Drupal\Core\Form\FormBuilderInterface
   */
  protected $formBuilder;

  /**
   * The report service.
   *
   * @var \Drupal\visitors\VisitorsReportInterface
   */
  protected $report;

  /**
   * The string translation service.
   *
   * @var \Drupal\Core\StringTranslation\TranslationInterface
   */
  protected $stringTranslation;

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): DeviceController {
    return new static(
      $container->get('date.formatter'),
      $container->get('form_builder'),
      $container->get('visitors.report'),
      $container->get('string_translation')
    );
  }

  /**
   * Constructs a DaysOfMonth object.
   *
   * @param \Drupal\Core\Datetime\DateFormatterInterface $date_formatter
   *   The date service.
   * @param \Drupal\Core\Form\FormBuilderInterface $form_builder
   *   The form builder service.
   * @param \Drupal\visitors\VisitorsReportInterface $report_service
   *   The report service.
   * @param \Drupal\Core\StringTranslation\TranslationInterface $string_translation
   *   The string translation service.
   */
  public function __construct(DateFormatterInterface $date_formatter, FormBuilderInterface $form_builder, VisitorsReportInterface $report_service, TranslationInterface $string_translation) {

    $this->date        = $date_formatter;
    $this->formBuilder = $form_builder;
    $this->report      = $report_service;
    $this->setStringTranslation($string_translation);
  }

  /**
   * Returns a days of month page.
   *
   * @return array
   *   A render array representing the days of month page content.
   */
  public function display(): array {

    $form = $this->formBuilder->getForm('Drupal\visitors\Form\DateFilter');
    $first_blocks = [];
    $second_blocks = [];

    $first_blocks['device_type'] = [
      '#view_id'      => 'visitors_device',
      '#view_display' => 'type',
      '#attributes'   => [
        'class' => ['layout-column--half'],
      ],
    ];
    $first_blocks['device_model'] = [
      '#view_id'      => 'visitors_device',
      '#view_display' => 'model',
      '#attributes'   => [
        'class' => ['layout-column--half'],
      ],
    ];

    $second_blocks['device_brand'] = [
      '#view_id'      => 'visitors_device',
      '#view_display' => 'brand',
      '#attributes'   => [
        'class' => ['layout-column--half'],
      ],
    ];
    $second_blocks['device_resolution'] = [
      '#view_id'      => 'visitors_device',
      '#view_display' => 'resolution',
      '#attributes'   => [
        'class' => ['layout-column--half'],
      ],
    ];

    return [
      'visitors_date_filter_form' => $form,
      'main' => [
        '#type' => 'container',
        '#attributes' => [
          'class' => ['visitors-main'],
        ],
        '1' => [
          $this->renderBlocks($first_blocks, 'layout-row'),
        ],
        '2' => [
          $this->renderBlocks($second_blocks, 'layout-row'),
        ],
      ],
      '#attached' => [
        'library' => [
          'visitors/visitors.report',
        ],
      ],
    ];
  }

}
